#  tests for cymem-2.0.4-py38h2531618_0 (this is a generated file);
print('===== testing package: cymem-2.0.4-py38h2531618_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import cymem
import pytest
import os

PACKAGE_DIR = os.path.abspath(os.path.dirname(cymem.__file__))
pytest.main([PACKAGE_DIR])
#  --- run_test.py (end) ---

print('===== cymem-2.0.4-py38h2531618_0 OK =====');
